==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/REVISIONCONTROL_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for REVISIONCONTROL_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="REVISIONCONTROL_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REVISIONCONTROLID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APPROVALLISTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APPROVEDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REQUESTEDBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEREQUESTED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REVISIONREASON" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "REVISIONCONTROL_Type", propOrder = {
    "revisioncontrolid",
    "approvallistid",
    "approvedate",
    "requestedby",
    "daterequested",
    "revisionreason"
})
public class REVISIONCONTROL_Type {

    @XmlElement(name = "REVISIONCONTROLID")
    protected REVISIONCONTROLID_Type revisioncontrolid;
    @XmlElement(name = "APPROVALLISTID")
    protected APPROVALLISTID_Type approvallistid;
    @XmlElement(name = "APPROVEDATE")
    protected DATETIME approvedate;
    @XmlElement(name = "REQUESTEDBY")
    protected PERSONID_Type requestedby;
    @XmlElement(name = "DATEREQUESTED")
    protected DATETIME daterequested;
    @XmlElement(name = "REVISIONREASON")
    protected String revisionreason;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the revisioncontrolid property.
     * 
     * @return
     *     possible object is
     *     {@link REVISIONCONTROLID_Type }
     *     
     */
    public REVISIONCONTROLID_Type getREVISIONCONTROLID() {
        return revisioncontrolid;
    }

    /**
     * Sets the value of the revisioncontrolid property.
     * 
     * @param value
     *     allowed object is
     *     {@link REVISIONCONTROLID_Type }
     *     
     */
    public void setREVISIONCONTROLID(REVISIONCONTROLID_Type value) {
        this.revisioncontrolid = value;
    }

    /**
     * Gets the value of the approvallistid property.
     * 
     * @return
     *     possible object is
     *     {@link APPROVALLISTID_Type }
     *     
     */
    public APPROVALLISTID_Type getAPPROVALLISTID() {
        return approvallistid;
    }

    /**
     * Sets the value of the approvallistid property.
     * 
     * @param value
     *     allowed object is
     *     {@link APPROVALLISTID_Type }
     *     
     */
    public void setAPPROVALLISTID(APPROVALLISTID_Type value) {
        this.approvallistid = value;
    }

    /**
     * Gets the value of the approvedate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getAPPROVEDATE() {
        return approvedate;
    }

    /**
     * Sets the value of the approvedate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setAPPROVEDATE(DATETIME value) {
        this.approvedate = value;
    }

    /**
     * Gets the value of the requestedby property.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getREQUESTEDBY() {
        return requestedby;
    }

    /**
     * Sets the value of the requestedby property.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setREQUESTEDBY(PERSONID_Type value) {
        this.requestedby = value;
    }

    /**
     * Gets the value of the daterequested property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEREQUESTED() {
        return daterequested;
    }

    /**
     * Sets the value of the daterequested property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEREQUESTED(DATETIME value) {
        this.daterequested = value;
    }

    /**
     * Gets the value of the revisionreason property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getREVISIONREASON() {
        return revisionreason;
    }

    /**
     * Sets the value of the revisionreason property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setREVISIONREASON(String value) {
        this.revisionreason = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}

==> eam-wshub-proxyclient-11.4-11-sources.jar: net/datastream/schemas/mp_fields/REVISIONCONTROL_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour REVISIONCONTROL_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="REVISIONCONTROL_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REVISIONCONTROLID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APPROVALLISTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APPROVEDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REQUESTEDBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEREQUESTED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REVISIONREASON" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "REVISIONCONTROL_Type", propOrder = {
    "revisioncontrolid",
    "approvallistid",
    "approvedate",
    "requestedby",
    "daterequested",
    "revisionreason"
})
public class REVISIONCONTROL_Type {

    @XmlElement(name = "REVISIONCONTROLID")
    protected REVISIONCONTROLID_Type revisioncontrolid;
    @XmlElement(name = "APPROVALLISTID")
    protected APPROVALLISTID_Type approvallistid;
    @XmlElement(name = "APPROVEDATE")
    protected DATETIME approvedate;
    @XmlElement(name = "REQUESTEDBY")
    protected PERSONID_Type requestedby;
    @XmlElement(name = "DATEREQUESTED")
    protected DATETIME daterequested;
    @XmlElement(name = "REVISIONREASON")
    protected String revisionreason;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Obtient la valeur de la propriété revisioncontrolid.
     * 
     * @return
     *     possible object is
     *     {@link REVISIONCONTROLID_Type }
     *     
     */
    public REVISIONCONTROLID_Type getREVISIONCONTROLID() {
        return revisioncontrolid;
    }

    /**
     * Définit la valeur de la propriété revisioncontrolid.
     * 
     * @param value
     *     allowed object is
     *     {@link REVISIONCONTROLID_Type }
     *     
     */
    public void setREVISIONCONTROLID(REVISIONCONTROLID_Type value) {
        this.revisioncontrolid = value;
    }

    /**
     * Obtient la valeur de la propriété approvallistid.
     * 
     * @return
     *     possible object is
     *     {@link APPROVALLISTID_Type }
     *     
     */
    public APPROVALLISTID_Type getAPPROVALLISTID() {
        return approvallistid;
    }

    /**
     * Définit la valeur de la propriété approvallistid.
     * 
     * @param value
     *     allowed object is
     *     {@link APPROVALLISTID_Type }
     *     
     */
    public void setAPPROVALLISTID(APPROVALLISTID_Type value) {
        this.approvallistid = value;
    }

    /**
     * Obtient la valeur de la propriété approvedate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getAPPROVEDATE() {
        return approvedate;
    }

    /**
     * Définit la valeur de la propriété approvedate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setAPPROVEDATE(DATETIME value) {
        this.approvedate = value;
    }

    /**
     * Obtient la valeur de la propriété requestedby.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getREQUESTEDBY() {
        return requestedby;
    }

    /**
     * Définit la valeur de la propriété requestedby.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setREQUESTEDBY(PERSONID_Type value) {
        this.requestedby = value;
    }

    /**
     * Obtient la valeur de la propriété daterequested.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEREQUESTED() {
        return daterequested;
    }

    /**
     * Définit la valeur de la propriété daterequested.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEREQUESTED(DATETIME value) {
        this.daterequested = value;
    }

    /**
     * Obtient la valeur de la propriété revisionreason.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getREVISIONREASON() {
        return revisionreason;
    }

    /**
     * Définit la valeur de la propriété revisionreason.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setREVISIONREASON(String value) {
        this.revisionreason = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}
